BanglaBulletList class

Bangla Bullet List

Constructors

BanglaBulletList({required List<String> items, double fontSize = 14, FontWeight fontWeight = pw.FontWeight.normal, BanglaFontType fontType = BanglaFontType.kalpurush, PdfColor color = PdfColors.black, String bullet = "- "})

Properties

box ↔ PdfRect?
The bounding box of this widget, calculated at layout time
getter/setter pairinherited
bullet String
final
canSpan bool
no setterinherited
color → PdfColor
final
fontSize double
final
fontType BanglaFontType
final
fontWeight → FontWeight
final
hashCode int
The hash code for this object.
no setterinherited
hasMoreWidgets bool
no setterinherited
items List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyContext(covariant WidgetContext context) → void
Called before relayout to restore the saved state and restart the layout in the same conditions
inherited
build(Context context) → Widget
cloneContext() → WidgetContext
Called after layout to save the state
inherited
debugPaint(Context context) → void
inherited
layout(Context context, BoxConstraints constraints, {bool parentUsesSize = false}) → void
First widget pass to calculate the children layout and bounding box
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Context context) → void
Draw itself and its children, according to the calculated box.offset
inherited
restoreContext(covariant WidgetContext context) → void
Apply the context for next page layout. Called before layout to prepare for next page
inherited
saveContext() → WidgetContext
Get unmodified mutable context object
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited