BanglaTextSpan class
A text span for BanglaRichText
Constructors
- BanglaTextSpan(String text, {double fontSize = 16, FontWeight fontWeight = pw.FontWeight.normal, PdfColor color = PdfColors.black, BanglaFontType fontType = BanglaFontType.kalpurush})
Properties
- color → PdfColor
-
final
- fontSize → double
-
final
- fontType → BanglaFontType
-
final
- fontWeight → FontWeight
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited