GetFonts class

Auto-generated font asset paths for easy access.

Constructors

GetFonts()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

adorOrjoma → const String
charuChandan → const String
charuChandanBloodDrip → const String
charukola → const String
diproAD → const String
jashir → const String
jashirItalic → const String
july → const String
julyItalic → const String
kalpona → const String
kalpurush → const String
lipiPadmo → const String
mayaboti → const String
mayabotiItalic → const String
nondon → const String
rajnigandha → const String
ruposhiBangla → const String
sonarKella → const String
sonarKellaItalic → const String
tomalicca → const String
trinoyon → const String
trinoyonItalic → const String