RichTextItem class

Represents a single text span in a PDF RichText.

Constructors

RichTextItem({required String text, double fontSize = 14, PdfColor color = PdfColors.black, required BanglaFontType fontType})
const

Properties

color → PdfColor
final
fontSize double
final
fontType BanglaFontType
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited