BanglaFontManager class
Singleton Font Manager for Bangla Fonts.
Constructors
- BanglaFontManager()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getFont(
BanglaFontType type) → Font -
Get a font synchronously (must call
initialize()before using) -
initialize(
) → Future< void> - Initialize and preload all fonts synchronously accessible later
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
isBanglaText(
String text) → bool - Function to load a TTF font from byte data and return the font family name