BanglaFontType enum
Enum for all Bangla fonts in this package.
Preview will be added in future releases.
- Inheritance
- Available extensions
Values
- adorOrjoma → const BanglaFontType
- charuChandan → const BanglaFontType
- charuChandanBloodDrip → const BanglaFontType
- charukola → const BanglaFontType
- kalpona → const BanglaFontType
- kalpurush → const BanglaFontType
- diproAD → const BanglaFontType
- jashirItalic → const BanglaFontType
- jashir → const BanglaFontType
- julyItalic → const BanglaFontType
-
A font configuration used to style text elements in an italic style. It is typically used to emphasize or differentiate text within the document.
- redJuly → const BanglaFontType
-
A font configuration used to style text elements. This font can be applied to widgets to customize their appearance.
- lipiPadmo → const BanglaFontType
- mayabotiItalic → const BanglaFontType
- mayaboti → const BanglaFontType
- nondon → const BanglaFontType
- rajnigandha → const BanglaFontType
- ruposhiBangla → const BanglaFontType
- sonarKellaItalic → const BanglaFontType
- sonarKella → const BanglaFontType
- tomalicca → const BanglaFontType
- trinoyonItalic → const BanglaFontType
- trinoyon → const BanglaFontType
- openSans → const BanglaFontType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
style(
{double fontSize = 16, FontWeight fontWeight = pw.FontWeight.normal, PdfColor color = PdfColors.black}) → TextStyle -
Available on BanglaFontType, provided by the BanglaFontTypeExtension extension
Get a ready-to-use TextStyle for this font -
text(
String text, {double fontSize = 16, FontWeight fontWeight = pw.FontWeight.normal, PdfColor color = PdfColors.black, TextAlign textAlign = pw.TextAlign.start}) → Widget -
Available on BanglaFontType, provided by the BanglaFontTypeExtension extension
Shortcut to create a BanglaText widget -
toString(
) → String -
A string representation of this object.
inherited
-
ts(
{double fontSize = 16, FontWeight fontWeight = pw.FontWeight.normal, PdfColor color = PdfColors.black}) → TextStyle -
Available on BanglaFontType, provided by the BanglaFontTypeExtension extension
Returns a ready-to-use pw.TextStyle with this Bangla font
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BanglaFontType> - A constant List of the values in this enum, in order of their declaration.