BanglaTable class
A reusable, customizable Bangla table widget for PDF documents.
Constructors
-
BanglaTable({required List<
List< data, double fontSize = 14, FontWeight fontWeight = pw.FontWeight.normal, BanglaFontType fontType = BanglaFontType.kalpurush, PdfColor headerColor = PdfColors.grey300, PdfColor borderColor = PdfColors.grey, Alignment cellAlignment = pw.Alignment.centerLeft, EdgeInsets cellPadding = const pw.EdgeInsets.all(6), Map<String> >int, TableColumnWidth> ? columnWidths, TextAlign headerAlignment = pw.TextAlign.center})
Properties
- borderColor → PdfColor
-
final
- box ↔ PdfRect?
-
The bounding box of this widget, calculated at layout time
getter/setter pairinherited
- canSpan → bool
-
no setterinherited
- cellAlignment → Alignment
-
final
- cellPadding → EdgeInsets
-
final
-
columnWidths
→ Map<
int, TableColumnWidth> ? -
final
-
data
→ List<
List< String> > -
final
- fontSize → double
-
final
- fontType → BanglaFontType
-
final
- fontWeight → FontWeight
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMoreWidgets → bool
-
no setterinherited
- headerAlignment → TextAlign
-
final
- headerColor → PdfColor
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
applyContext(
covariant WidgetContext context) → void -
Called before relayout to restore the saved state and
restart the layout in the same conditions
inherited
-
build(
Context context) → Widget -
cloneContext(
) → WidgetContext -
Called after layout to save the state
inherited
-
debugPaint(
Context context) → void -
inherited
-
layout(
Context context, BoxConstraints constraints, {bool parentUsesSize = false}) → void -
First widget pass to calculate the children layout and
bounding box
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Context context) → void -
Draw itself and its children, according to the calculated
box.offsetinherited -
restoreContext(
covariant WidgetContext context) → void -
Apply the context for next page layout.
Called before layout to prepare for next page
inherited
-
saveContext(
) → WidgetContext -
Get unmodified mutable context object
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited